@@ -35,7 +35,7 @@ class WlanDriverStatusPlugin(StatusMenuItem):
 	def changeDrivers(self, button, action):
 		if not self.disableButtons:
 			failed = False
-			#self.Notifications.notify(str(button.get_active())+"|"+action)
+			#self.Notifications.notify(str(button.get_active())+'|'+action)
 			#Current drivers
 			realDrivers = self.getDriverStatus()
 			#Wanted drivers
@@ -52,21 +52,21 @@ class WlanDriverStatusPlugin(StatusMenuItem):
 				wantedDrivers = 2
 			#Do we really already have the wanted drivers?
 			if realDrivers == wantedDrivers:
-				if realDrivers == 0: self.Notifications.notify("Wlan is already in disabled")
-				elif realDrivers == 1: self.Notifications.notify("Stock drivers are already in use")
-				elif realDrivers == 2: self.Notifications.notify("Bleeding Edge drivers are already in use")
+				if realDrivers == 0: self.Notifications.notify('Wlan is already in disabled')
+				elif realDrivers == 1: self.Notifications.notify('Stock drivers are already in use')
+				elif realDrivers == 2: self.Notifications.notify('Bleeding Edge drivers are already in use')
 			#Change the drivers
 			else:
-				folder = ""
+				folder = ''
 				if wantedDrivers == 2:
 					folder = self.Config.getFolder()
 					if self.Config.checkFolder(folder) == False:
 						failed = True
 				if not failed:
-					self.DriverLoader.load(folder, wantedDrivers)
+					wantedDrivers = self.DriverLoader.load(folder, wantedDrivers)
 			if failed:
 				self.updateButtons(self.getDriverStatus())
-				self.Notifications.notify("Couldn't find Bleeding Edge drivers")
+				self.Notifications.notify('Couldn\'t find Bleeding Edge drivers')
 				gobject.idle_add(self.openSetupDialog)
 			else:
 				self.updateButtons(wantedDrivers)
@@ -79,7 +79,7 @@ class WlanDriverStatusPlugin(StatusMenuItem):
 		self.disableButtons = True
 		if driver == 0:
 			self.disableButton.set_active(False)
-			self.set_status_area_icon(gtk.gdk.pixbuf_new_from_file('/usr/share/icons/hicolor/48x48/hildon/wifi-off.png'))
+			self.set_status_area_icon(gtk.gdk.pixbuf_new_from_file('/usr/share/icons/hicolor/18x18/hildon/wifi-off.png'))
 			#self.driverButton.setDisabled(True)
 		elif driver == 1:
 			self.disableButton.set_active(True)
@@ -94,7 +94,7 @@ class WlanDriverStatusPlugin(StatusMenuItem):
 		self.disableButtons = False
 
 	def getDriverStatus(self):
-		f = open('/proc/modules', "r")
+		f = open('/proc/modules', 'r')
 		for line in f.readlines():
 			if line.startswith('wl1251'):
 				f.close()
@@ -120,25 +120,37 @@ class DriverLoader(Thread):
 		if driver == 2:	output = commands.getoutput('cd '+folder+'; sudo /sbin/load-bleeding-edge-drivers.sh')
 		elif driver == 1: output = commands.getoutput('sudo /sbin/load-stock-drivers.sh')
 		else: output = commands.getoutput('sudo /sbin/unload-drivers.sh')
+		#Check driver status
+		realDrivers = self.Parent.getDriverStatus()
+		if realDrivers != driver:
+			if driver == 0:
+				output2 = 'Drivers were not unloaded'
+			else:
+				output2 = 'Drivers were not loaded'
+			if len(output) == 0:
+				output = output2
+			else:
+				output += '\n'+output2
+			
 		#Notify about loading stopping
 		if len(output)>0:
-			if driver == 0:	self.Parent.Notifications.notify('Error while disabling WLAN, error:\n'+output)
-			elif driver == 1: self.Parent.Notifications.notify('Error while loading Stock drivers, error:\n'+output)
-			elif driver == 2: self.Parent.Notifications.notify('Error while loading Bleeding Edge drivers, error:\n'+output)
+			if driver == 0:	self.Parent.Notifications.notify(output, 'Error while disabling WLAN')
+			elif driver == 1: self.Parent.Notifications.notify(output, 'Error while loading Stock drivers')
+			elif driver == 2: self.Parent.Notifications.notify(output, 'Error while loading Bleeding Edge drivers')
 		else:
 			if driver == 0:	self.Parent.Notifications.notify('Disabled WLAN')
 			elif driver == 1: self.Parent.Notifications.notify('Loaded Stock drivers')
 			elif driver == 2: self.Parent.Notifications.notify('Loaded Bleeding Edge drivers')
-		if driver > 0:
-			time.sleep(1)
-			proxy = self.Parent.bus.get_object('com.nokia.icd_ui', '/com/nokia/icd_ui', 'com.nokia.icd_ui')
-			proxy.show_conn_dlg(False)
+			if driver > 0:
+				proxy = self.Parent.bus.get_object('com.nokia.icd_ui', '/com/nokia/icd_ui', 'com.nokia.icd_ui')
+				proxy.show_conn_dlg(False)
+		return realDrivers
 
 class Notifications:
 	def __init__(self, Parent):
 		self.bus = Parent.bus
 
-	def notify(self, message):
+	def notify(self, message, title=False):
 		if hasattr(self, 'object') == False or hasattr(self, 'interface') == False:
 			try:
 				self.object = self.bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
@@ -147,7 +159,23 @@ class Notifications:
 				pass
 		if hasattr(self, 'object') and hasattr(self, 'interface'):
 			try:
-				self.interface.SystemNoteInfoprint(message)
+				if title:
+					dialog = gtk.Dialog(title)
+					dialog.set_geometry_hints(min_height=800)
+					panArea = hildon.PannableArea()
+					panArea.set_property('mov-mode', hildon.MOVEMENT_MODE_VERT)
+					textview = hildon.TextView()
+					textbuffer = gtk.TextBuffer()
+					textbuffer.set_text(message)
+					textview.set_buffer(textbuffer)
+					textview.set_editable(False)
+					textview.set_wrap_mode(gtk.WRAP_WORD)
+					#textview.set_cursor_visible(False)
+					panArea.add_with_viewport(textview)
+					dialog.vbox.add(panArea)
+					dialog.show_all()
+				else:
+					self.interface.SystemNoteInfoprint(message)
 			except:
 				pass
 
@@ -216,19 +244,19 @@ class SetupDialog(gtk.Dialog, Thread):
 		if type(folder).__name__ == 'str':
 			if self.Parent.Config.checkFolder(folder):
 				self.Parent.Config.setFolder(folder)
-				self.Parent.Notifications.notify("Folder selected succesfully")
+				self.Parent.Notifications.notify('Folder selected succesfully')
 				self.destroy()
 				self.Parent.click(None)
 			else:
-				self.Parent.Notifications.notify("Couldn't find all needed files from:\n"+folder)
+				self.Parent.Notifications.notify('Couldn\'t find all needed files from:\n'+folder)
 		else:
-			self.Parent.Notifications.notify("Please select the folder which contains the Bleeding Edge drivers")
+			self.Parent.Notifications.notify('Please select the folder which contains the Bleeding Edge drivers')
 
 	def download(self, ignore):
 		#Connect to internet if needed
 		try:
 			s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-			s.connect(("files.laasonen.net",80))
+			s.connect(('files.laasonen.net',80))
 			connection = True
 		except:
 			connection = False
@@ -237,7 +265,7 @@ class SetupDialog(gtk.Dialog, Thread):
 			for i in range(10):
 				try:
 					s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-					s.connect(("files.laasonen.net",80))
+					s.connect(('files.laasonen.net',80))
 					connection = True
 					break
 				except:
@@ -260,32 +288,32 @@ class SetupDialog(gtk.Dialog, Thread):
 				from urllib import urlretrieve
 				#Download
 				try:
-					bar = ProgressBar(title='Downloading Bleeding Edge Drivers', label="Downloading Bleeding Edge Drivers")
+					bar = ProgressBar(title='Downloading Bleeding Edge Drivers', label='Downloading Bleeding Edge Drivers')
 					def report(block_count, block_size, total_size):
 						if block_count == 0:
 							bar.set(0, total_size)
 						bar.inc(block_size)
 					if urlretrieve(self.driverLocation+''+self.driverName, self.driverName, reporthook=report):
-						self.Parent.Notifications.notify("Drivers downloaded succesfully")
+						self.Parent.Notifications.notify('Drivers downloaded succesfully')
 						extract = True
 					else:
-						self.Parent.Notifications.notify("Download failed")
+						self.Parent.Notifications.notify('Download failed')
 					bar.__del__()
 				except:
-					self.Parent.Notifications.notify("Download canceled")
+					self.Parent.Notifications.notify('Download canceled')
 			else:
-				self.Parent.Notifications.notify("Please select a folder for Bleeding Edge drivers")
+				self.Parent.Notifications.notify('Please select a folder for Bleeding Edge drivers')
 		else:
-			self.Parent.Notifications.notify("Couldn't create connection")
+			self.Parent.Notifications.notify('Couldn\'t create connection')
 		if extract:
 			try:
 				import tarfile
-				tar = tarfile.open(self.driverName, "r:gz")
+				tar = tarfile.open(self.driverName, 'r:gz')
 				tar.extractall()
 				self.Parent.Config.setFolder(folder+'/'+self.driverFolder)
-				self.Parent.Notifications.notify("Success, drivers are now installed")
+				self.Parent.Notifications.notify('Success, drivers are now installed')
 			except:
-				self.Parent.Notifications.notify("Extraction failed")
+				self.Parent.Notifications.notify('Extraction failed')
 
 	def helpDialog(self, ignore):
 		dialog = gtk.Dialog('Help')
